# Configuration Reference

`pangeo-forge-runner` uses the very flexible
[traitlets](https://traitlets.readthedocs.io/en/stable/) system (also used by
the Jupyter & Dask ecosystems) for configuration.  This page links out to all
the configurable parts of `pangeo-forge-runner`.  Configuration can be set via
[command-line
options](https://traitlets.readthedocs.io/en/stable/config.html#command-line-arguments),
or via a [dedicated config
file](https://traitlets.readthedocs.io/en/stable/config.html#configuration-objects-and-files)
in `.json` or `.py` format

```{toctree}
:maxdepth: 1

bakery
storage
commands
glossary
```
